@@ -16,7 +16,7 @@ function kontaktformular_admin()
     $kontaktformular_thankyou_page = getconfig("kontaktformular_thankyou_page");
     $email = getconfig("contact_form_mail_to");
     
-    $pages = getAllSystemNames();
+    $pages = getAllSlugs();
     
     ?>
 
